function [ difference_rtc_software ] = calc_rtc_software_difference( p_profile )
%CALC_RTC_SOFTWARE_DIFFERENCE Summary of this function goes here
%   Detailed explanation goes here

software_datevec = ...
    datevec( ...
        datetime([ ...
        fliplr(p_profile.OVERALL_MISSION_INFORMATION.start_date), ...
        p_profile.OVERALL_MISSION_INFORMATION.start_time 0 ...
    ]) ...
    + seconds(p_profile.PROFILE_TECHNICAL_DATA.xmit_ascent_start_time) ...
);
software_time = software_datevec(4:6);
% get internal clock (RTC) @ 2000m
rtc_time = p_profile.PROFILE_DATA( ...
    p_profile.PROFILE_DATA(:, 7) == max(p_profile.PROFILE_DATA(:, 7)), ...
    2:4);
% if there are multiple pressure levels get the one with the
% earliest time
rtc_time = sortrows(rtc_time, [1:3]);
if isempty(rtc_time) || isempty(software_datevec) % prevent errors if empty
    difference_rtc_software = NaN;
    return;
end
rtc_time = rtc_time(end, :);

rtc_datevec = datevec(datetime([software_datevec(1:3), rtc_time]));

if (any(rtc_time(1) == 21:23) && any(software_time(1) == 0:3))
    % RTC is more trustworthy, so reduce the software date by 1
    rtc_datevec = datevec(datetime([software_datevec(1:3), rtc_time]) - days(1));
elseif (any(rtc_time(1) == 0:3) && any(software_time(1) == 21:23))
    % same here, but now add 1 day
    rtc_datevec = datevec(datetime([software_datevec(1:3), rtc_time]) + days(1));
end

difference_rtc_software = etime(rtc_datevec, software_datevec) + 10;

end

