function [ boolean ] = compare( p_profile_a, p_profile_b )
%COMPARE Checks if the input profiles are equal.
%   Both input profiles are compared to each other. If one of the
%   underlying struct/cell/double values are not equal, it will return false.
%
%   Parameters:
%   p_profile_a, p_profile_b: Profiles to be compared. Ideally they are
%                             previously loaded by nemo.profile.load()
%
%   Returns:
%   boolean:            True if both profiles are equal.

%% Initialize return variables
boolean = true;
%% TODO: Parameter check

%% Comparing profiles

compare_variables(p_profile_a, p_profile_b);

    function compare_variables(p_a, p_b)
        
        switch class(p_a)
            case {'double', 'logical'}
                if (all(all(isnan(p_a))) && all(all(isnan(p_b))))
                    return;
                elseif (all(all(isnan(p_a))) && ~all(all(isnan(p_b))))
                    boolean = false;
                    return;
                end
                if (~strcmp(num2str(p_a), num2str(p_b)))
                    boolean = false;
                    return;
                end
            case 'char'
                if (~strcmp(p_a, p_b))
                    boolean = false;
                    return;
                end
            case 'struct'
                fieldnames_a = fieldnames(p_a);
                fieldnames_b = fieldnames(p_b);
                if (~isequaln(fieldnames_a, fieldnames_b))
                    boolean = false;
                    return;
                end
                for i = 1:length(fieldnames_a)
                    compare_variables(p_a.(fieldnames_a{i}), p_b.(fieldnames_b{i}));
                end
                
            case 'cell'
                [la, ca] = size(p_a);
                [lb, cb] = size(p_b);
                if ((la ~= lb) || (ca ~= cb))
                    boolean = false;
                    return;
                end
                if ((ca > 1) && (la > 1))
                    for i = 1:la
                        for k = 1:ca
                            compare_variables(p_a{i}{k}, p_b{i}{k});
                        end
                    end
                else
                    la = size(p_a);
                    for i = 1:la
                        compare_variables(p_a{i}, p_b{i});
                    end
                end
        end
        
        
        
        
        
    end

end

