function [ mapped_profile ] = map_to( p_profile, p_mapping, p_skip_undefined )
%MAP_TO Summary of this function goes here
%   Detailed explanation goes here

%% Initialize return variable
mapped_profile = false;

%% Parameter check
if ~isstruct(p_profile) || ~isstruct(p_mapping)
    disp([mfilename ': Please check your input parameter!']);
    return
end

%% Map parameters
mapped_profile = struct;

fnames_profile = fieldnames(p_profile);

for i = 1:length(fnames_profile)
    
    % check if mapping exists for this field
    if ~isfield(p_mapping, fnames_profile{i})
        if exist('p_skip_undefined', 'var') && ~p_skip_undefined
            mapped_profile.(fnames_profile{i}) = p_profile.(fnames_profile{i});
        end
        continue
    end
    
    current_field = p_profile.(fnames_profile{i});
    
    if ~isstruct(current_field) % we only want to modify structs atm
        continue
    end
    
    mapped_profile.(fnames_profile{i}) = struct;
    
    % get the fieldnames in the struct
    subfnames = fieldnames(current_field);
    for k = 1:length(subfnames)
        
        if ~isfield(p_mapping.(fnames_profile{i}), subfnames{k})
            if exist('p_skip_undefined', 'var') && ~p_skip_undefined
                mapped_profile.(fnames_profile{i}).(subfnames{k}) = p_profile.(fnames_profile{i}).(subfnames{k});
            end
            continue
        end
        
        % check if the previous value is the same
        if isfield(mapped_profile.(fnames_profile{i}), (p_mapping.(fnames_profile{i}).(subfnames{k})))
            % append the value instead of copying
            mapped_profile.(fnames_profile{i}).(p_mapping.(fnames_profile{i}).(subfnames{k})) = ...
                [ ...
                    mapped_profile.(fnames_profile{i}).(p_mapping.(fnames_profile{i}).(subfnames{k})) ...
                    p_profile.(fnames_profile{i}).(subfnames{k})
                ];
            continue
        end
        
        % check if there are multiple values in the field
        values = strsplit(p_mapping.(fnames_profile{i}).(subfnames{k}), ',');
        if length(values) > 1
            for m = 1:length(values)
                mapped_profile.(fnames_profile{i}).(values{m}) = p_profile.(fnames_profile{i}).(subfnames{k})(m);
            end
            continue
        end
        
        mapped_profile.(fnames_profile{i}).(p_mapping.(fnames_profile{i}).(subfnames{k})) = p_profile.(fnames_profile{i}).(subfnames{k});
        
    end
   
end

end

